# Battery Model
from oes.battery.battery_model import BatteryModel, get_default_battery_params
from oes.battery.battery import AbstractBattery, SimulatedBattery

# Base controller
from oes.controllers.abstract_battery_controller import AbstractBatteryController

# Basic controllers
from oes.controllers.basic.donothing import DoNothingController
from oes.controllers.basic.charge import ChargeController
from oes.controllers.basic.discharge import DischargeController

# Rule-based controllers
from oes.controllers.rule_based.solar_self_consumption import SolarSelfConsumptionController
from oes.controllers.rule_based.import_tariff_optimisation import ImportTariffOptimisationController
from oes.controllers.rule_based.spotprice_arbitrage_naive import SpotPriceArbitrageNaiveController

# Optimisation-program based controllers
from oes.controllers.optimisation_based.dynamic_program import DynamicProgramController
from oes.controllers.optimisation_based.spotprice_arbitrage_optimal import SpotPriceArbitrageOptimalController

# Schedulers
from oes.schedulers.dp_scheduler import DPScheduler

# Utility
from oes.util import general, cost_function_helpers



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(name="oes",
      version="1.0.2",
      description="Optimal operation of energy storage",
      long_description=long_description,
      long_description_content_type="text/markdown",
      url="https://github.com/solstice-ai/optimal-energy-storage",
      author="Julian de Hoog",
      author_email='julian@dehoog.ca',
      license="MIT",
      packages=["oes"],
      install_requires=[
            'pandas',
      ],
      tests_require=[
            'pytest',
            'pandas'
      ],
      zip_safe=False)
